@@ -112,7 +112,7 @@ impl<'a> HuobiWSClient<'a> {
     }
 
     fn on_misc_msg(msg: &str) -> MiscMessage {
-        let resp = serde_json::from_str::<HashMap<String, Value>>(&msg);
+        let resp = serde_json::from_str::<HashMap<String, Value>>(msg);
         if resp.is_err() {
             error!("{} is not a JSON string, {}", msg, EXCHANGE_NAME);
             return MiscMessage::Misc;
