@@ -261,7 +261,7 @@ impl<'a> WSClientInternal<'a> {
                             error!("Server closed connection, exiting now...");
                             // self.reconnect();
                             std::thread::sleep(Duration::from_secs(5));
-                            break; // fail fast, pm2 will restart
+                            std::process::exit(0); // fail fast, pm2 will restart
                         }
                         Error::AlreadyClosed => {
                             error!("Impossible to happen, fix the bug in the code");
@@ -282,7 +282,7 @@ impl<'a> WSClientInternal<'a> {
                                 );
                                 // self.reconnect();
                                 std::thread::sleep(Duration::from_secs(5));
-                                break; // fail fast, pm2 will restart
+                                std::process::exit(0); // fail fast, pm2 will restart
                             }
                         }
                         Error::Protocol(protocol_err) => {
@@ -290,7 +290,7 @@ impl<'a> WSClientInternal<'a> {
                                 error!("ResetWithoutClosingHandshake");
                                 // self.reconnect();
                                 std::thread::sleep(Duration::from_secs(5));
-                                break; // fail fast, pm2 will restart
+                                std::process::exit(0); // fail fast, pm2 will restart
                             } else {
                                 error!(
                                     "Protocol error thrown from read_message(): {}",
@@ -316,7 +316,7 @@ impl<'a> WSClientInternal<'a> {
                         num_unanswered_ping,
                         start_timstamp.elapsed().as_secs()
                     );
-                    break; // fail fast, pm2 will restart
+                    std::process::exit(0); // fail fast, pm2 will restart
                 }
                 if last_ping_timestamp.elapsed() >= Duration::from_secs(interval_and_msg.0 / 2) {
                     info!("Sending ping: {}", interval_and_msg.1);
@@ -339,7 +339,7 @@ impl<'a> WSClientInternal<'a> {
                     num_read_timeout,
                     start_timstamp.elapsed().as_secs()
                 );
-                break; // fail fast, pm2 will restart
+                std::process::exit(0); // fail fast, pm2 will restart
             }
 
             if let Some(seconds) = duration {
